(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      6569,        223]
NotebookOptionsPosition[      5303,        169]
NotebookOutlinePosition[      5920,        197]
CellTagsIndexPosition[      5823,        191]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Syntax", "Section",
 CellChangeTimes->{{3.503797381820464*^9, 3.503797387145678*^9}}],

Cell[BoxData[
 RowBox[{"SeedRandom", "[", 
  RowBox[{"Method", "\[Rule]", "\"\<...\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5037972954725113`*^9, 3.503797302152878*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Methods", "Section",
 CellTags->"Methods",
 CellID->185956823],

Cell[BoxData[GridBox[{
   {"\"\<Congruential\>\"", Cell["\<\
linear congruential generator (low\[Hyphen]quality randomness)\
\>", "TableText"]},
   {"\"\<ExtendedCA\>\"", Cell[
    "extended cellular automaton generator (default)", "TableText"]},
   {"\"\<Legacy\>\"", Cell[TextData[{
     "default generators prior to ",
     StyleBox["Mathematica",
      FontSlant->"Italic"],
     " 6.0"
    }], "TableText"]},
   {"\"\<MersenneTwister\>\"", Cell[
    "Mersenne Twister shift register generator", "TableText"]},
   {"\"\<MKL\>\"", Cell["\<\
Intel MKL generator (Intel\[Hyphen]based systems)\
\>", "TableText"]},
   {"\"\<ParallelGenerator\>\"", Cell["\<\
used for initializing and seeding generators for parallel computations.\
\>", "TableText"]},
   {"\"\<ParallelMersenneTwister\>\"", Cell[TextData[{
     "set of 1024 Mersenne Twister generators of period ",
     Cell[BoxData[
      FormBox[
       RowBox[{
        SuperscriptBox["2", "4423"], "-", "1"}], TraditionalForm]], 
      "InlineMath"]
    }], "TableText"]},
   {"\"\<Rule30CA\>\"", Cell["Wolfram rule 30 generator", "TableText"]}
  }]], "DefinitionBox",
 CellID->154028361],

Cell[CellGroupData[{

Cell["MKL Submethods", "Subsection",
 CellChangeTimes->{{3.5037972852446547`*^9, 3.5037972884800262`*^9}},
 CellID->57850632],

Cell[BoxData[
 RowBox[{"SeedRandom", "[", 
  RowBox[{"Method", "\[Rule]", 
   RowBox[{"{", 
    RowBox[{"\"\<MKL\>\"", ",", "\"\<...\>\""}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.503797317730462*^9, 3.503797332100018*^9}}],

Cell[TextData[{
 "The ",
 Cell[BoxData["\"\<MKL\>\""], "InlineFormula"],
 " method uses the random number generators provided in Intel's MKL \
libraries. The MKL libraries are platform dependent. The ",
 Cell[BoxData["\"\<MKL\>\""], "InlineFormula"],
 " method is available on Microsoft Windows (32-bit, 64-bit), Linux x86 \
(32-bit, 64-bit), and Linux Itanium systems."
}], "Text",
 CellID->483061491],

Cell[BoxData[GridBox[{
   {"\"\<MCG31\>\"", Cell[
    "31-bit multiplicative congruential generator", "TableText"]},
   {"\"\<MCG59\>\"", Cell[
    "59-bit multiplicative congruential generator", "TableText"]},
   {"\"\<MRG32K3A\>\"", Cell["\<\
combined multiple recursive generators with two components of order 3\
\>", "TableText"]},
   {"\"\<MersenneTwister\>\"", Cell[
    "Mersenne Twister shift register generator", "TableText"]},
   {"\"\<R250\>\"", Cell[
    "generalized feedback shift register generator", "TableText"]},
   {"\"\<WichmannHill\>\"", Cell["\<\
Wichmann\[Dash]Hill combined multiplicative congruential generators\
\>", "TableText"]},
   {"\"\<Niederreiter\>\"", Cell[
    "Niederreiter low-discrepancy sequence", "TableText"]},
   {"\"\<Sobol\>\"", Cell["Sobol low-discrepancy sequence", "TableText"]}
  }]], "DefinitionBox",
 CellID->369023658]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining Your Own Generator", "Section",
 CellTags->"Generators",
 CellID->215995533],

Cell[BoxData[GridBox[{
   {
    RowBox[{"Random`InitializeGenerator", "[", 
     RowBox[{
      StyleBox["gsym", "TI"], ",", 
      StyleBox["opts", "TI"]}], "]"}], "\[SpanFromLeft]"},
   {"", Cell[TextData[{
     "initialize the generator ",
     Cell[BoxData[
      StyleBox["gsym", "TI"]], "InlineFormula"],
     " with options ",
     Cell[BoxData[
      StyleBox["opts", "TI"]], "InlineFormula"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellChangeTimes->{{3.5037973918375893`*^9, 3.503797393690791*^9}},
 CellID->391001025],

Cell[BoxData[GridBox[{
   {"GeneratesBitsQ", Cell[TextData[{
     "set to ",
     Cell[BoxData[
      ButtonBox["True",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/True"]], "InlineFormula"],
     " if the method generates bits"
    }], "TableText"]},
   {"GeneratesIntegersQ", Cell[TextData[{
     "set to ",
     Cell[BoxData[
      ButtonBox["True",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/True"]], "InlineFormula"],
     " if the method generates integers for a given range"
    }], "TableText"]},
   {"GeneratesRealsQ", Cell[TextData[{
     "set to ",
     Cell[BoxData[
      ButtonBox["True",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/True"]], "InlineFormula"],
     " if the method generates reals for a given range and precision"
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->41499560]
}, Open  ]]
},
WindowSize->{856, 627},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Methods"->{
  Cell[885, 33, 68, 2, 67, "Section",
   CellTags->"Methods",
   CellID->185956823]},
 "Generators"->{
  Cell[3809, 118, 91, 2, 67, "Section",
   CellTags->"Generators",
   CellID->215995533]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Methods", 5606, 180},
 {"Generators", 5709, 184}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 91, 1, 67, "Section"],
Cell[673, 25, 175, 3, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[885, 33, 68, 2, 67, "Section",
 CellTags->"Methods",
 CellID->185956823],
Cell[956, 37, 1142, 30, 144, "DefinitionBox",
 CellID->154028361],
Cell[CellGroupData[{
Cell[2123, 71, 125, 2, 34, "Subsection",
 CellID->57850632],
Cell[2251, 75, 232, 5, 27, "Input"],
Cell[2486, 82, 402, 9, 41, "Text",
 CellID->483061491],
Cell[2891, 93, 869, 19, 142, "DefinitionBox",
 CellID->369023658]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3809, 118, 91, 2, 67, "Section",
 CellTags->"Generators",
 CellID->215995533],
Cell[3903, 122, 534, 16, 40, "DefinitionBox",
 CellID->391001025],
Cell[4440, 140, 847, 26, 56, "DefinitionBox",
 CellID->41499560]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

